@@ -23,6 +23,10 @@
 #include "message-view.h"
 #define MESSAGE_TYPE message_get_type()
 
+#define PREFERENCES_SCHEMA "org.gnome.anjuta.message-manager"
+#define COLOR_ERROR "msgman-color-error"
+#define COLOR_WARNING "msgman-color-warning"
+
 struct _MessageViewPrivate
 {
 	//guint num_messages;
@@ -36,17 +40,19 @@ struct _MessageViewPrivate
 	
 	gint adj_chgd_hdlr;
 	
-	/* Messages filter buttons */
-	GtkWidget *normal, *info, *warn, *error;
-	guint normal_count, info_count, warn_count, error_count;
-
+	/* Messages filter */
+	MessageViewFlags flags;
+	gint normal_count;
+	gint warn_count;
+	gint error_count;
+	gint info_count;
+	
 	/* Properties */
 	gchar *label;
 	gchar *pixmap;
 	gboolean highlite;
 	
-	/* gconf notification ids */
-	GList *notify_ids;
+	GSettings* settings;
 };
 
 typedef struct
@@ -92,8 +98,8 @@ ask_user_for_save_uri (GtkWindow* parent)
 	gchar* uri;
 
        	dialog = gtk_file_chooser_dialog_new (_("Save file as"), parent,
-		GTK_FILE_CHOOSER_ACTION_SAVE, GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
-		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, NULL);
+		GTK_FILE_CHOOSER_ACTION_SAVE, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+		GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT, NULL);
 
 	if(gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT)
 	{
@@ -279,8 +285,8 @@ on_message_event (GObject* object, GdkEvent* event, gpointer data)
 	{
 		switch(((GdkEventKey *)event)->keyval)
 		{
-			case GDK_space:
-			case GDK_Return:
+			case GDK_KEY_space:
+			case GDK_KEY_Return:
 			{
 				const gchar* message =
 					ianjuta_message_view_get_current_message(IANJUTA_MESSAGE_VIEW (view), NULL);
@@ -324,14 +330,6 @@ on_message_event (GObject* object, GdkEvent* event, gpointer data)
 	return FALSE;
 }
 
-static void
-on_filter_buttons_toggled (GtkToggleButton *toggle, gpointer user_data) 
-{
-	MessageView *msgview = MESSAGE_VIEW (user_data);
-	
-	gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (msgview->privat->filter));
-}
-
 static void 
 on_adjustment_changed (GtkAdjustment* adj, gpointer data)
 {
@@ -437,11 +435,7 @@ static void
 message_view_dispose (GObject *obj)
 {
 	MessageView *mview = MESSAGE_VIEW (obj);
-	if (mview->privat->notify_ids)
-	{
-		prefs_finalize (mview);
-		mview->privat->notify_ids = NULL;
-	}
+	prefs_finalize (mview);
 	if (mview->privat->tree_view)
 	{
 		mview->privat->tree_view = NULL;
@@ -463,8 +457,6 @@ message_view_finalize (GObject *obj)
 static void
 message_view_instance_init (MessageView * self)
 {
-	GtkWidget *vbox;
-	GtkWidget *filter_buttons_box;
 	GtkWidget *scrolled_win;
 	GtkCellRenderer *renderer;
 	GtkCellRenderer *renderer_pixbuf;
@@ -479,72 +471,7 @@ message_view_instance_init (MessageView * self)
 
 	/* Init private data */
 	self->privat->line_buffer = g_strdup("");
-	self->privat->normal_count = 0;
-	self->privat->info_count = 0;
-	self->privat->warn_count = 0;
-	self->privat->error_count = 0;
-
-	/* Create filter buttons */
-	vbox = gtk_hbox_new (FALSE, 0);
-	filter_buttons_box = gtk_vbox_new (FALSE, 1);
-	
-	self->privat->normal = gtk_toggle_button_new_with_label (_("No Messages"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->privat->normal), TRUE);
-	gtk_button_set_focus_on_click (GTK_BUTTON (self->privat->normal), FALSE);
-	gtk_button_set_relief (GTK_BUTTON (self->privat->normal), GTK_RELIEF_HALF);
-	gtk_button_set_alignment (GTK_BUTTON (self->privat->normal), 0.0, 0.5);
-	gtk_widget_show (self->privat->normal);
-	g_signal_connect (G_OBJECT (self->privat->normal), "toggled",
-					  G_CALLBACK (on_filter_buttons_toggled), self);
-	
-	self->privat->info = gtk_toggle_button_new_with_label (_("No Infos"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->privat->info), TRUE);
-	gtk_button_set_focus_on_click (GTK_BUTTON (self->privat->info), FALSE);
-	gtk_button_set_relief (GTK_BUTTON (self->privat->info), GTK_RELIEF_HALF);
-	gtk_button_set_alignment (GTK_BUTTON (self->privat->info), 0.0, 0.5);
-	gtk_button_set_image (GTK_BUTTON (self->privat->info), 
-						  gtk_image_new_from_stock (GTK_STOCK_INFO, 
-													GTK_ICON_SIZE_BUTTON));
-	gtk_widget_show (self->privat->info);
-	g_signal_connect (G_OBJECT (self->privat->info), "toggled",
-					  G_CALLBACK (on_filter_buttons_toggled), self);
-	
-	self->privat->warn = gtk_toggle_button_new_with_label (_("No Warnings"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->privat->warn), TRUE);
-	gtk_button_set_focus_on_click (GTK_BUTTON (self->privat->warn), FALSE);
-	gtk_button_set_relief (GTK_BUTTON (self->privat->warn), GTK_RELIEF_HALF);
-	gtk_button_set_alignment (GTK_BUTTON (self->privat->warn), 0.0, 0.5);
-	/* FIXME: There is not GTK_STOCK_DIALOG_WARNING. */
-	gtk_button_set_image (GTK_BUTTON (self->privat->warn), 
-						  gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING, 
-													GTK_ICON_SIZE_BUTTON));
-	gtk_widget_show (self->privat->warn);
-	g_signal_connect (G_OBJECT (self->privat->warn), "toggled",
-					  G_CALLBACK (on_filter_buttons_toggled), self);
-	
-	self->privat->error = gtk_toggle_button_new_with_label (_("No Errors"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->privat->error), TRUE);
-	gtk_button_set_focus_on_click (GTK_BUTTON (self->privat->error), FALSE);
-	gtk_button_set_relief (GTK_BUTTON (self->privat->error), GTK_RELIEF_HALF);
-	gtk_button_set_alignment (GTK_BUTTON (self->privat->error), 0.0, 0.5);
-	gtk_button_set_image (GTK_BUTTON (self->privat->error), 
-						  gtk_image_new_from_stock (GTK_STOCK_STOP, 
-													GTK_ICON_SIZE_BUTTON));
-	gtk_widget_show (self->privat->error);
-	g_signal_connect (G_OBJECT (self->privat->error), "toggled",
-					  G_CALLBACK (on_filter_buttons_toggled), self);
-	
-	gtk_box_pack_start (GTK_BOX (filter_buttons_box), GTK_WIDGET (self->privat->normal),
-						FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (filter_buttons_box), GTK_WIDGET (self->privat->info),
-						FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (filter_buttons_box), GTK_WIDGET (self->privat->warn),
-						FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (filter_buttons_box), GTK_WIDGET (self->privat->error),
-						FALSE, FALSE, 0);
-	
-	gtk_widget_show (filter_buttons_box);
-	
+	self->privat->flags = 0xF;
 	
 	/* Create the tree widget */
 	model = gtk_list_store_new (N_COLUMNS, G_TYPE_STRING,
@@ -608,22 +535,8 @@ message_view_instance_init (MessageView * self)
 									 G_CALLBACK (on_adjustment_changed), self);
 	g_signal_connect(G_OBJECT(adj), "value_changed",
 					 G_CALLBACK(on_adjustment_value_changed), self);
-
-	/* Add it to the dockitem */
-	if (gtk_widget_get_default_direction () == GTK_TEXT_DIR_LTR) {
-		gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (scrolled_win),
-							TRUE, TRUE, 0);
-		gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (filter_buttons_box),
-							FALSE, FALSE, 0);
-	} else {
-		gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (filter_buttons_box),
-							FALSE, FALSE, 0);
-		gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (scrolled_win),
-							TRUE, TRUE, 0);
-	}
 	
-	gtk_widget_show (vbox);
-	gtk_container_add (GTK_CONTAINER (self), vbox);
+	gtk_container_add (GTK_CONTAINER (self), scrolled_win);
 	
 	/* Connect signals */
 	g_signal_connect (G_OBJECT(self->privat->tree_view), "event", 
@@ -894,7 +807,7 @@ static gboolean message_view_save_as(MessageView* view, gchar* uri)
 
 	ok = TRUE;
 	gtk_tree_model_get_iter_first (model, &iter);
-	while (gtk_tree_model_iter_next (model, &iter))
+	do
 	{
 		Message *message;
 
@@ -903,24 +816,24 @@ static gboolean message_view_save_as(MessageView* view, gchar* uri)
 		{
 			if (message->details && (strlen (message->details) > 0))
 			{
-				if (!g_output_stream_write (os, message->details, strlen (message->details), NULL, NULL))
+				if (g_output_stream_write (os, message->details, strlen (message->details), NULL, NULL) < 0)
 				{
 					ok = FALSE;
 				}
 			}
 			else
 			{
-				if (!g_output_stream_write (os, message->summary, strlen (message->summary), NULL, NULL))
+				if (g_output_stream_write (os, message->summary, strlen (message->summary), NULL, NULL) < 0)
 				{
 					ok = FALSE;
 				}
 			}
-			if (!g_output_stream_write (os, "\n", 1, NULL, NULL))
+			if (g_output_stream_write (os, "\n", 1, NULL, NULL) < 0)
 			{
 				ok = FALSE;
 			}
 		}
-	}
+	} while (gtk_tree_model_iter_next (model, &iter));
 	g_output_stream_close (os, NULL, NULL);
 	g_object_unref (os);
 	g_object_unref (file);
@@ -994,7 +907,7 @@ pref_change_color (MessageView *mview, IAnjutaMessageViewType type,
 	GtkTreeIter iter;
 	gboolean success;
 	
-	color = anjuta_preferences_get (anjuta_preferences_default(), color_pref_key);
+	color = g_settings_get_string (mview->privat->settings, color_pref_key);
 	store = GTK_LIST_STORE (mview->privat->model);
 	success = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (store), &iter);
 	while (success)
@@ -1013,47 +926,35 @@ pref_change_color (MessageView *mview, IAnjutaMessageViewType type,
 
 
 static void
-on_notify_color (AnjutaPreferences* prefs, const gchar* key,
-                 const gchar* value, gpointer user_data)
+on_notify_color (GSettings* settings, const gchar* key,
+                 gpointer user_data)
 {
-	pref_change_color (MESSAGE_VIEW (user_data),
-					   IANJUTA_MESSAGE_VIEW_TYPE_WARNING,
-					   key);
+	if (g_str_equal (key, COLOR_ERROR))
+	    pref_change_color (MESSAGE_VIEW (user_data),
+	                       IANJUTA_MESSAGE_VIEW_TYPE_ERROR,
+	                       key);
+	else
+	    pref_change_color (MESSAGE_VIEW (user_data),
+	                       IANJUTA_MESSAGE_VIEW_TYPE_WARNING,
+	                       key);
 }
 
 static void
 prefs_init (MessageView *mview)
 {
-	gint id;
-	id = anjuta_preferences_notify_add_string (anjuta_preferences_default (),
-	                                           "messages.color.error",
-	                                           on_notify_color,
-	                                           mview,
-	                                           NULL);
-	mview->privat->notify_ids = g_list_append (mview->privat->notify_ids,
-	                                           GINT_TO_POINTER (id));	
-	id = anjuta_preferences_notify_add_string (anjuta_preferences_default (),
-	                                      "messages.color.warning",
-	                                      on_notify_color,
-	                                      mview,
-	                                      NULL);
-	mview->privat->notify_ids = g_list_append (mview->privat->notify_ids,
-	                                         GINT_TO_POINTER (id));
+	mview->privat->settings = g_settings_new (PREFERENCES_SCHEMA);
+	g_signal_connect (mview->privat->settings, "changed::" COLOR_ERROR,
+	                  G_CALLBACK (on_notify_color), mview);
+	g_signal_connect (mview->privat->settings, "changed::" COLOR_WARNING,
+	                  G_CALLBACK (on_notify_color), mview);
 }
 
 static void
 prefs_finalize (MessageView *mview)
 {
-	GList *node;
-	node = mview->privat->notify_ids;
-	while (node)
-	{
-		anjuta_preferences_notify_remove (anjuta_preferences_default(),
-										  GPOINTER_TO_INT (node->data));
-		node = g_list_next (node);
-	}
-	g_list_free (mview->privat->notify_ids);
-	mview->privat->notify_ids = NULL;
+	if (mview->privat->settings)
+		g_object_unref (mview->privat->settings);
+	mview->privat->settings = NULL;
 }
 
 /* IAnjutaMessageView interface implementation */
@@ -1092,36 +993,6 @@ imessage_view_buffer_append (IAnjutaMessageView * message_view,
 	}
 }
 
-static void 
-update_button_labels (MessageView* view)
-{
-	gchar* temp;
-	
-	temp = g_strdup_printf(ngettext ("%d Message", "%d Messages", 
-									 view->privat->normal_count),
-						   view->privat->normal_count);
-	gtk_button_set_label (GTK_BUTTON (view->privat->normal), temp);
-	g_free(temp);
-	
-	temp = g_strdup_printf(ngettext ("%d Info", "%d Infos", 
-									 view->privat->info_count),
-						   view->privat->info_count);
-	gtk_button_set_label (GTK_BUTTON (view->privat->info), temp);
-	g_free (temp);
-	temp = g_strdup_printf(ngettext ("%d Warning", "%d Warnings", 
-									 view->privat->warn_count),
-						   view->privat->warn_count);	
-	gtk_button_set_label (GTK_BUTTON (view->privat->warn), temp);
-	g_free (temp);
-	temp = g_strdup_printf(ngettext ("%d Error", "%d Errors", 
-									 view->privat->error_count),
-						   view->privat->error_count);	
-	gtk_button_set_label (GTK_BUTTON (view->privat->error), temp);
-	g_free (temp);
-	
-}
-
-
 static void
 imessage_view_append (IAnjutaMessageView *message_view,
 					  IAnjutaMessageViewType type,
@@ -1157,15 +1028,13 @@ imessage_view_append (IAnjutaMessageView *message_view,
 				stock_id = GTK_STOCK_INFO;
 				break;
 			case IANJUTA_MESSAGE_VIEW_TYPE_WARNING:
-				color = anjuta_preferences_get (anjuta_preferences_default(),
-									  "messages.color.warning");
+				color = g_settings_get_string (view->privat->settings, COLOR_WARNING);
 				/* FIXME: There is no GTK_STOCK_WARNING which would fit better here */
 				view->privat->warn_count++;
 				stock_id = GTK_STOCK_DIALOG_WARNING;
 				break;
 			case IANJUTA_MESSAGE_VIEW_TYPE_ERROR:
-				color = anjuta_preferences_get (anjuta_preferences_default(),
-									  "messages.color.error");
+				color = g_settings_get_string (view->privat->settings, COLOR_ERROR);
 				view->privat->error_count++;
 				stock_id = GTK_STOCK_STOP;
 				break;
@@ -1174,7 +1043,6 @@ imessage_view_append (IAnjutaMessageView *message_view,
 				view->privat->normal_count++;
 		}
 	}
-	update_button_labels (view);
 	
 	/* Add the message to the tree */
 	store = GTK_LIST_STORE (view->privat->model);
@@ -1230,12 +1098,6 @@ imessage_view_clear (IAnjutaMessageView *message_view, GError **e)
 	view->privat->info_count = 0;
 	view->privat->warn_count = 0;
 	view->privat->error_count = 0;
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (view->privat->normal), TRUE);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (view->privat->info), TRUE);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (view->privat->warn), TRUE);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (view->privat->error), TRUE);
-	
-	update_button_labels (view);
 	
 	store = GTK_LIST_STORE (view->privat->model);
 	gtk_list_store_clear (store);
@@ -1365,17 +1227,46 @@ message_view_tree_view_filter (GtkTreeModel *model, GtkTreeIter  *iter,
 
 	if (msg != NULL) {
 		if (msg->type == IANJUTA_MESSAGE_VIEW_TYPE_NORMAL) {
-			return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (msgview->privat->normal));
+			return msgview->privat->flags & MESSAGE_VIEW_SHOW_NORMAL;
 		} else if (msg->type == IANJUTA_MESSAGE_VIEW_TYPE_INFO) {
-			return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (msgview->privat->info));
+			return msgview->privat->flags & MESSAGE_VIEW_SHOW_INFO;
 		} else if (msg->type == IANJUTA_MESSAGE_VIEW_TYPE_WARNING) {
-			return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (msgview->privat->warn));
+			return msgview->privat->flags & MESSAGE_VIEW_SHOW_WARNING;
 		} else if (msg->type == IANJUTA_MESSAGE_VIEW_TYPE_ERROR) {
-			return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (msgview->privat->error));
+			return msgview->privat->flags & MESSAGE_VIEW_SHOW_ERROR;
 		} else return TRUE;
 	} else return FALSE;
 }
 
+MessageViewFlags
+message_view_get_flags (MessageView* view)
+{
+	return view->privat->flags;
+}
+
+void message_view_set_flags (MessageView* view, MessageViewFlags flags)
+{
+	view->privat->flags = flags;
+	gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER(view->privat->filter));
+}
+
+gint message_view_get_count (MessageView* view, MessageViewFlags flags)
+{
+	switch (flags)
+	{
+		case MESSAGE_VIEW_SHOW_NORMAL:
+			return view->privat->normal_count;
+		case MESSAGE_VIEW_SHOW_INFO:
+			return view->privat->info_count;
+		case MESSAGE_VIEW_SHOW_WARNING:
+			return view->privat->warn_count;
+		case MESSAGE_VIEW_SHOW_ERROR:
+			return view->privat->error_count;
+		default:
+			g_assert_not_reached ();
+	}
+}
+
 ANJUTA_TYPE_BEGIN(MessageView, message_view, GTK_TYPE_HBOX);
 ANJUTA_TYPE_ADD_INTERFACE(imessage_view, IANJUTA_TYPE_MESSAGE_VIEW);
-ANJUTA_TYPE_END;
+ANJUTA_TYPE_END;
\ No newline at end of file
